@@ -26,11 +26,9 @@
 #include "vndbfetcher.h"
 #include "../collections/gamecollection.h"
 #include "../images/imagefactory.h"
-#include "../utils/guiproxy.h"
-#include "../utils/string_utils.h"
+#include "../utils/mapvalue.h"
 #include "../entry.h"
 #include "../fieldformat.h"
-#include "../core/filehandler.h"
 #include "../tellico_debug.h"
 
 #include <KLocalizedString>
@@ -40,7 +38,6 @@
 #include <QFile>
 #include <QTextStream>
 #include <QGridLayout>
-#include <QTextCodec>
 #include <QJsonDocument>
 #include <QJsonObject>
 #include <QJsonValue>
@@ -86,6 +83,18 @@ void VNDBFetcher::search() {
   m_started = true;
   m_data.clear();
 
+  QByteArray get("get vn basic,details ");
+  switch(request().key()) {
+    case Title:
+      get += "(search ~ \"" + request().value().toUtf8() + "\")";
+      break;
+
+    default:
+      myWarning() << source() << "- key not recognized:" << request().key();
+      stop();
+      return;
+  }
+
   if(!m_socket) {
     m_socket = new QTcpSocket(this);
     QObject::connect(m_socket, &QTcpSocket::readyRead,     this, &VNDBFetcher::slotRead);
@@ -99,12 +108,14 @@ void VNDBFetcher::search() {
 #endif
   }
   if(!m_isConnected) {
+    myLog() << "Connecting to" << VNDB_HOSTNAME << "at port" << VNDB_PORT;
     m_socket->connectToHost(QLatin1String(VNDB_HOSTNAME), VNDB_PORT);
   }
 
   //the client ver only wants digits, I think?
+  static const QRegularExpression notDigits(QStringLiteral("[^0-9.]"));
   QString clientVersion(QStringLiteral(TELLICO_VERSION));
-  clientVersion.remove(QRegularExpression(QStringLiteral("[^0-9.]")));
+  clientVersion.remove(notDigits);
 
   QByteArray login = "login {"
                              "\"protocol\":1,"
@@ -113,30 +124,19 @@ void VNDBFetcher::search() {
   login += clientVersion.toUtf8() + "\"}";
   login.append(0x04);
   if(m_socket->waitForConnected()) {
-//    myDebug() << login;
+    myLog() << "Sending login information:" << login;
     m_socket->write(login);
     m_socket->waitForReadyRead(5000);
     if(m_state == PreLogin) {
       // login did not work
+      myLog() << "Login did not succeed";
       stop();
       return;
     }
   }
 
-  QByteArray get("get vn basic,details ");
-  switch(request().key()) {
-    case Title:
-      get += "(search ~ \"" + request().value().toUtf8() + "\")";
-      break;
-
-    default:
-      myWarning() << source() << "- key not recognized:" << request().key();
-      stop();
-      return;
-  }
-
   m_state = GetVN;
-//  myDebug() << get << m_state;
+  myLog() << "Sending get request:" << get;
   get.append(0x04);
   m_socket->write(get);
 }
@@ -164,7 +164,7 @@ Tellico::Data::EntryPtr VNDBFetcher::fetchEntryHook(uint uid_) {
        + " and patch = false and type = \"complete\")";
 
   m_state = GetRelease;
-//  myDebug() << get << m_state;
+  myLog() << "Sending get request:" << get;
   get.append(0x04);
   m_socket->write(get);
   // 5 sec was not long enough
@@ -188,6 +188,7 @@ Tellico::Data::EntryPtr VNDBFetcher::fetchEntryHook(uint uid_) {
   entry->setField(QStringLiteral("vn-id"), QString());
 
   if(m_socket->isValid()) {
+    myLog() << "Disconnecting from host";
     m_socket->disconnectFromHost();
     m_state = PreLogin;
   }
@@ -216,8 +217,9 @@ bool VNDBFetcher::verifyData() {
     QJsonDocument doc = QJsonDocument::fromJson(m_data.mid(5));
     QVariantMap result = doc.object().toVariantMap();
     if(result.contains(QStringLiteral("msg"))) {
-      myDebug() << "Data error:" << result.value(QStringLiteral("msg")).toString();
-      message(result.value(QStringLiteral("msg")).toString(), MessageHandler::Error);
+      const auto msg = result.value(QStringLiteral("msg")).toString();
+      myDebug() << "Data error:" << msg;
+      message(msg, MessageHandler::Error);
     }
     return false;
   }
@@ -253,7 +255,6 @@ void VNDBFetcher::parseVNResults() {
   QFile f(QString::fromLatin1("/tmp/vndbtest.json"));
   if(f.open(QIODevice::WriteOnly)) {
     QTextStream t(&f);
-    t.setCodec("UTF-8");
     t << m_data;
   }
   f.close();
@@ -270,7 +271,7 @@ void VNDBFetcher::parseVNResults() {
   QVariantMap topResultMap = doc.object().toVariantMap();
   QVariantList resultList = topResultMap.value(QStringLiteral("items")).toList();
   if(resultList.isEmpty()) {
-    myDebug() << "no results";
+    myLog() << "No results";
     stop();
     return;
   }
@@ -333,7 +334,6 @@ void VNDBFetcher::parseReleaseResults(Data::EntryPtr entry_) {
   QFile f(QString::fromLatin1("/tmp/vndb-release.json"));
   if(f.open(QIODevice::WriteOnly)) {
     QTextStream t(&f);
-    t.setCodec("UTF-8");
     t << m_data;
   }
   f.close();
@@ -349,7 +349,7 @@ void VNDBFetcher::parseReleaseResults(Data::EntryPtr entry_) {
   QVariantMap topResultMap = doc.object().toVariantMap();
   QVariantList resultList = topResultMap.value(QStringLiteral("items")).toList();
   if(resultList.isEmpty()) {
-    myDebug() << "no results";
+    myLog() << "No results";
     return;
   }
 
