@@ -46,7 +46,9 @@ private Q_SLOTS:
   void testDuplicateLoans();
   void testDuplicateBorrowers();
   void testLocalImage();
+  void testLocalImageLink();
   void testRemoteImage();
+  void testRemoteImageLink();
   void testDataImage();
   void testXMLHandler();
   void testXMLHandler_data();
